package com.gyf.immersionbar;

import android.app.Application;
import android.database.ContentObserver;
import android.net.Uri;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.provider.Settings;
import java.util.ArrayList;
import java.util.Iterator;
/* loaded from: classes.dex */
final class EMUI3NavigationBarObserver extends ContentObserver {
    private Application mApplication;
    private ArrayList<ImmersionCallback> mCallbacks;
    private Boolean mIsRegister;

    /* JADX INFO: Access modifiers changed from: package-private */
    public static EMUI3NavigationBarObserver getInstance() {
        return NavigationBarObserverInstance.INSTANCE;
    }

    private EMUI3NavigationBarObserver() {
        super(new Handler(Looper.getMainLooper()));
        this.mIsRegister = false;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void register(Application application) {
        Uri uriFor;
        this.mApplication = application;
        if (Build.VERSION.SDK_INT >= 17 && this.mApplication != null && this.mApplication.getContentResolver() != null && !this.mIsRegister.booleanValue() && (uriFor = Settings.System.getUriFor("navigationbar_is_min")) != null) {
            this.mApplication.getContentResolver().registerContentObserver(uriFor, true, this);
            this.mIsRegister = true;
        }
    }

    @Override // android.database.ContentObserver
    public void onChange(boolean z) {
        super.onChange(z);
        if (Build.VERSION.SDK_INT >= 17 && this.mApplication != null && this.mApplication.getContentResolver() != null && this.mCallbacks != null && !this.mCallbacks.isEmpty()) {
            int i = Settings.System.getInt(this.mApplication.getContentResolver(), "navigationbar_is_min", 0);
            Iterator<ImmersionCallback> it = this.mCallbacks.iterator();
            while (it.hasNext()) {
                it.next().onNavigationBarChange(i != 1);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void addOnNavigationBarListener(ImmersionCallback immersionCallback) {
        if (immersionCallback != null) {
            if (this.mCallbacks == null) {
                this.mCallbacks = new ArrayList<>();
            }
            if (!this.mCallbacks.contains(immersionCallback)) {
                this.mCallbacks.add(immersionCallback);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void removeOnNavigationBarListener(ImmersionCallback immersionCallback) {
        if (immersionCallback != null && this.mCallbacks != null) {
            this.mCallbacks.remove(immersionCallback);
        }
    }

    /* loaded from: classes.dex */
    private static class NavigationBarObserverInstance {
        private static final EMUI3NavigationBarObserver INSTANCE = new EMUI3NavigationBarObserver();

        private NavigationBarObserverInstance() {
        }
    }
}
