package com.gyf.immersionbar;

import android.app.Activity;
import android.app.Dialog;
import android.content.res.Configuration;
import android.os.Build;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.Fragment;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public class ImmersionDelegate implements Runnable {
    private BarProperties mBarProperties;
    private ImmersionBar mImmersionBar;
    private int mNotchHeight;
    private OnBarListener mOnBarListener;

    /* JADX INFO: Access modifiers changed from: package-private */
    public ImmersionDelegate(Object obj) {
        if (obj instanceof Activity) {
            if (this.mImmersionBar == null) {
                this.mImmersionBar = new ImmersionBar((Activity) obj);
            }
        } else if (obj instanceof Fragment) {
            if (this.mImmersionBar == null) {
                if (obj instanceof DialogFragment) {
                    this.mImmersionBar = new ImmersionBar((DialogFragment) obj);
                } else {
                    this.mImmersionBar = new ImmersionBar((Fragment) obj);
                }
            }
        } else if ((obj instanceof android.app.Fragment) && this.mImmersionBar == null) {
            if (obj instanceof android.app.DialogFragment) {
                this.mImmersionBar = new ImmersionBar((android.app.DialogFragment) obj);
            } else {
                this.mImmersionBar = new ImmersionBar((android.app.Fragment) obj);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public ImmersionDelegate(Activity activity, Dialog dialog) {
        if (this.mImmersionBar == null) {
            this.mImmersionBar = new ImmersionBar(activity, dialog);
        }
    }

    public ImmersionBar get() {
        return this.mImmersionBar;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onActivityCreated(Configuration configuration) {
        barChanged(configuration);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onResume() {
        if (this.mImmersionBar != null) {
            this.mImmersionBar.onResume();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onDestroy() {
        this.mBarProperties = null;
        if (this.mImmersionBar != null) {
            this.mImmersionBar.onDestroy();
            this.mImmersionBar = null;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onConfigurationChanged(Configuration configuration) {
        if (this.mImmersionBar != null) {
            this.mImmersionBar.onConfigurationChanged(configuration);
            barChanged(configuration);
        }
    }

    private void barChanged(Configuration configuration) {
        if (this.mImmersionBar != null && this.mImmersionBar.initialized() && Build.VERSION.SDK_INT >= 19) {
            this.mOnBarListener = this.mImmersionBar.getBarParams().onBarListener;
            if (this.mOnBarListener != null) {
                Activity activity = this.mImmersionBar.getActivity();
                if (this.mBarProperties == null) {
                    this.mBarProperties = new BarProperties();
                }
                this.mBarProperties.setPortrait(configuration.orientation == 1);
                int rotation = activity.getWindowManager().getDefaultDisplay().getRotation();
                if (rotation == 1) {
                    this.mBarProperties.setLandscapeLeft(true);
                    this.mBarProperties.setLandscapeRight(false);
                } else if (rotation == 3) {
                    this.mBarProperties.setLandscapeLeft(false);
                    this.mBarProperties.setLandscapeRight(true);
                } else {
                    this.mBarProperties.setLandscapeLeft(false);
                    this.mBarProperties.setLandscapeRight(false);
                }
                activity.getWindow().getDecorView().post(this);
            }
        }
    }

    @Override // java.lang.Runnable
    public void run() {
        if (this.mImmersionBar != null && this.mImmersionBar.getActivity() != null) {
            Activity activity = this.mImmersionBar.getActivity();
            BarConfig barConfig = new BarConfig(activity);
            this.mBarProperties.setStatusBarHeight(barConfig.getStatusBarHeight());
            this.mBarProperties.setNavigationBar(barConfig.hasNavigationBar());
            this.mBarProperties.setNavigationBarHeight(barConfig.getNavigationBarHeight());
            this.mBarProperties.setNavigationBarWidth(barConfig.getNavigationBarWidth());
            this.mBarProperties.setActionBarHeight(barConfig.getActionBarHeight());
            boolean hasNotchScreen = NotchUtils.hasNotchScreen(activity);
            this.mBarProperties.setNotchScreen(hasNotchScreen);
            if (hasNotchScreen && this.mNotchHeight == 0) {
                this.mNotchHeight = NotchUtils.getNotchHeight(activity);
                this.mBarProperties.setNotchHeight(this.mNotchHeight);
            }
            this.mOnBarListener.onBarChange(this.mBarProperties);
        }
    }
}
