package com.gyf.immersionbar;

import android.app.Application;
import android.database.ContentObserver;
import android.net.Uri;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.provider.Settings;
import java.util.ArrayList;
import java.util.Iterator;
/* loaded from: classes.dex */
final class NavigationBarObserver extends ContentObserver {
    private Application mApplication;
    private Boolean mIsRegister;
    private ArrayList<OnNavigationBarListener> mListeners;

    /* JADX INFO: Access modifiers changed from: package-private */
    public static NavigationBarObserver getInstance() {
        return NavigationBarObserverInstance.INSTANCE;
    }

    private NavigationBarObserver() {
        super(new Handler(Looper.getMainLooper()));
        this.mIsRegister = false;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void register(Application application) {
        this.mApplication = application;
        if (Build.VERSION.SDK_INT >= 17 && this.mApplication != null && this.mApplication.getContentResolver() != null && !this.mIsRegister.booleanValue()) {
            Uri uri = null;
            if (OSUtils.isMIUI()) {
                uri = Settings.Global.getUriFor("force_fsg_nav_bar");
            } else if (OSUtils.isEMUI()) {
                if (OSUtils.isEMUI3_x() || Build.VERSION.SDK_INT < 21) {
                    uri = Settings.System.getUriFor("navigationbar_is_min");
                } else {
                    uri = Settings.Global.getUriFor("navigationbar_is_min");
                }
            }
            if (uri != null) {
                this.mApplication.getContentResolver().registerContentObserver(uri, true, this);
                this.mIsRegister = true;
            }
        }
    }

    @Override // android.database.ContentObserver
    public void onChange(boolean z) {
        int i;
        super.onChange(z);
        if (Build.VERSION.SDK_INT >= 17 && this.mApplication != null && this.mApplication.getContentResolver() != null && this.mListeners != null && !this.mListeners.isEmpty()) {
            if (OSUtils.isMIUI()) {
                i = Settings.Global.getInt(this.mApplication.getContentResolver(), "force_fsg_nav_bar", 0);
            } else if (!OSUtils.isEMUI()) {
                i = 0;
            } else if (OSUtils.isEMUI3_x() || Build.VERSION.SDK_INT < 21) {
                i = Settings.System.getInt(this.mApplication.getContentResolver(), "navigationbar_is_min", 0);
            } else {
                i = Settings.Global.getInt(this.mApplication.getContentResolver(), "navigationbar_is_min", 0);
            }
            Iterator<OnNavigationBarListener> it = this.mListeners.iterator();
            while (it.hasNext()) {
                it.next().onNavigationBarChange(i != 1);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void addOnNavigationBarListener(OnNavigationBarListener onNavigationBarListener) {
        if (onNavigationBarListener != null) {
            if (this.mListeners == null) {
                this.mListeners = new ArrayList<>();
            }
            if (!this.mListeners.contains(onNavigationBarListener)) {
                this.mListeners.add(onNavigationBarListener);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void removeOnNavigationBarListener(OnNavigationBarListener onNavigationBarListener) {
        if (onNavigationBarListener != null && this.mListeners != null) {
            this.mListeners.remove(onNavigationBarListener);
        }
    }

    /* loaded from: classes.dex */
    private static class NavigationBarObserverInstance {
        private static final NavigationBarObserver INSTANCE = new NavigationBarObserver();

        private NavigationBarObserverInstance() {
        }
    }
}
